tasty-quickcheck-0.8.3: QuickCheck support for the Tasty test framework.

Safe HaskellNone

Test.Tasty.QuickCheck

Contents

Description

This module allows to use QuickCheck properties in tasty.

Synopsis

Documentation

testProperty :: Testable a => TestName -> a -> TestTreeSource

Create a Test for a QuickCheck Testable property

newtype QuickCheckTests Source

Number of test cases for QuickCheck to generate

Constructors

QuickCheckTests Int 

newtype QuickCheckReplay Source

Replay a previous test using a replay token

Constructors

QuickCheckReplay (Maybe (QCGen, Int)) 

newtype QuickCheckShowReplay Source

If a test case fails unexpectedly, show the replay token

Constructors

QuickCheckShowReplay Bool 

newtype QuickCheckMaxSize Source

Size of the biggest test cases

Constructors

QuickCheckMaxSize Int 

newtype QuickCheckMaxRatio Source

Maximum number of of discarded tests per successful test before giving up.

Constructors

QuickCheckMaxRatio Int 

Internal

This is exposed for testing purposes and not considered as a part of the public API. You probably shouldn't need it.

newtype QC Source

Constructors

QC Property 

Instances

Typeable QC 
IsTest QC