| Safe Haskell | None |
|---|
Test.Tasty.QuickCheck
Contents
Description
This module allows to use QuickCheck properties in tasty.
- testProperty :: Testable a => TestName -> a -> TestTree
- newtype QuickCheckTests = QuickCheckTests Int
- newtype QuickCheckReplay = QuickCheckReplay (Maybe (QCGen, Int))
- newtype QuickCheckShowReplay = QuickCheckShowReplay Bool
- newtype QuickCheckMaxSize = QuickCheckMaxSize Int
- newtype QuickCheckMaxRatio = QuickCheckMaxRatio Int
- module Test.QuickCheck
- newtype QC = QC Property
Documentation
testProperty :: Testable a => TestName -> a -> TestTreeSource
Create a Test for a QuickCheck Testable property
newtype QuickCheckTests Source
Number of test cases for QuickCheck to generate
Constructors
| QuickCheckTests Int |
Instances
| Enum QuickCheckTests | |
| Eq QuickCheckTests | |
| Integral QuickCheckTests | |
| Num QuickCheckTests | |
| Ord QuickCheckTests | |
| Real QuickCheckTests | |
| Typeable QuickCheckTests | |
| IsOption QuickCheckTests |
newtype QuickCheckReplay Source
Replay a previous test using a replay token
Constructors
| QuickCheckReplay (Maybe (QCGen, Int)) |
Instances
| Typeable QuickCheckReplay | |
| IsOption QuickCheckReplay |
newtype QuickCheckShowReplay Source
If a test case fails unexpectedly, show the replay token
Constructors
| QuickCheckShowReplay Bool |
Instances
newtype QuickCheckMaxSize Source
Size of the biggest test cases
Constructors
| QuickCheckMaxSize Int |
Instances
| Enum QuickCheckMaxSize | |
| Eq QuickCheckMaxSize | |
| Integral QuickCheckMaxSize | |
| Num QuickCheckMaxSize | |
| Ord QuickCheckMaxSize | |
| Real QuickCheckMaxSize | |
| Typeable QuickCheckMaxSize | |
| IsOption QuickCheckMaxSize |
newtype QuickCheckMaxRatio Source
Maximum number of of discarded tests per successful test before giving up.
Constructors
| QuickCheckMaxRatio Int |
Instances
| Enum QuickCheckMaxRatio | |
| Eq QuickCheckMaxRatio | |
| Integral QuickCheckMaxRatio | |
| Num QuickCheckMaxRatio | |
| Ord QuickCheckMaxRatio | |
| Real QuickCheckMaxRatio | |
| Typeable QuickCheckMaxRatio | |
| IsOption QuickCheckMaxRatio |
module Test.QuickCheck
Internal
This is exposed for testing purposes and not considered as a part of the public API. You probably shouldn't need it.